@@ -11,6 +11,7 @@
 
 #include "backends/abstractcontact.h"
 #include "backends/basepersonsdatasource.h"
+#include "imageprovideruri_p.h"
 #include "metacontact_p.h"
 #include "personmanager_p.h"
 #include "personpluginmanager.h"
@@ -108,6 +109,7 @@ QHash<int, QByteArray> PersonsModel::roleNames() const
     roles.insert(PersonVCardRole, "personVCard");
     roles.insert(ContactsVCardRole, "contactsVCard");
     roles.insert(PhoneNumberRole, "phoneNumber");
+    roles.insert(PhotoImageProviderUri, "photoImageProviderUri");
     return roles;
 }
 
@@ -175,6 +177,8 @@ QVariant PersonsModelPrivate::dataForContact(const QString &personUri, const Abs
         return person->customProperty(QStringLiteral("all-groups"));
     case PersonsModel::PhoneNumberRole:
         return person->customProperty(AbstractContact::PhoneNumberProperty);
+    case PersonsModel::PhotoImageProviderUri:
+        return ::photoImageProviderUri(personUri);
     }
     return QVariant();
 }
@@ -480,4 +484,5 @@ QVariant PersonsModel::contactCustomProperty(const QModelIndex &index, const QSt
     }
 }
 
+#include "moc_personsmodel.cpp"
 #include "personsmodel.moc"
