@@ -7,16 +7,17 @@
 #ifndef KPEOPLEWIDGETS_ACTIONS_H
 #define KPEOPLEWIDGETS_ACTIONS_H
 
-#include <QList>
-#include <qobjectdefs.h>
 #include <kpeople/widgets/kpeoplewidgets_export.h>
+#include <qobjectdefs.h>
+
+#include <QList>
 
 class QString;
 class QObject;
 class QAction;
 namespace KPeople
 {
-Q_NAMESPACE
+Q_NAMESPACE_EXPORT(KPEOPLEWIDGETS_EXPORT)
 class PersonData;
 
 /**
@@ -31,7 +32,7 @@ enum ActionType {
     VideoCallAction,
     SendEmailAction,
     SendFileAction,
-    OtherAction = 100
+    OtherAction = 100,
 };
 Q_ENUM_NS(ActionType)
 
