@@ -39,11 +39,11 @@ public:
         NameRole = Qt::DisplayRole,
         UriRole = Qt::UserRole + 1,
         PixmapRole,
-        MergeReasonRole
+        MergeReasonRole,
     };
 
     explicit MergeDialog(QWidget *parent = nullptr);
-    ~MergeDialog();
+    ~MergeDialog() override;
 
     /**
      * Specifies which PersonsModel will be used to look for duplicates.
@@ -51,13 +51,13 @@ public:
     void setPersonsModel(PersonsModel *model);
 
 private Q_SLOTS:
-    void searchForDuplicates();
-    void searchForDuplicatesFinished(KJob *);
-    void onMergeButtonClicked();
+    KPEOPLEWIDGETS_NO_EXPORT void searchForDuplicates();
+    KPEOPLEWIDGETS_NO_EXPORT void searchForDuplicatesFinished(KJob *);
+    KPEOPLEWIDGETS_NO_EXPORT void onMergeButtonClicked();
 
 private:
-    QStandardItem *itemMergeContactFromMatch(bool parent, const KPeople::Match &match);
-    void feedDuplicateModelFromMatches(const QList<Match> &matches);
+    KPEOPLEWIDGETS_NO_EXPORT QStandardItem *itemMergeContactFromMatch(bool parent, const KPeople::Match &match);
+    KPEOPLEWIDGETS_NO_EXPORT void feedDuplicateModelFromMatches(const QList<Match> &matches);
 
     MergeDialogPrivate *const d_ptr;
     Q_DECLARE_PRIVATE(MergeDialog)
